import React, { useEffect, useState } from 'react';
import InlineToolbar from './InlineToolbar';
import { EditorState, Modifier, RichUtils } from 'draft-js';
import { getSelectionInlineStyle } from '../../utils/inlineUtils';

interface IProps {
  editorState: EditorState;
  onChange: (editorState: EditorState) => void;
}

const Toolbar = (props: IProps): JSX.Element => {
  const { editorState, onChange } = props;
  const [currentStyles, setCurrentStyles] = useState<Record<string, boolean>>(
    {},
  );
  const toggleInlineStyle = style => {
    const newStyle = style === 'monospace' ? 'CODE' : style.toUpperCase();
    let newState = RichUtils.toggleInlineStyle(editorState, newStyle);
    if (style === 'subscript' || style === 'superscript') {
      const removeStyle = style === 'subscript' ? 'SUPERSCRIPT' : 'SUBSCRIPT';
      const contentState = Modifier.removeInlineStyle(
        newState.getCurrentContent(),
        newState.getSelection(),
        removeStyle,
      );
      newState = EditorState.push(
        newState,
        contentState,
        'change-inline-style',
      );
    }
    if (newState) {
      onChange(newState);
    }
  };

  const changeKeys = (style?: Record<string, boolean>) => {
    if (style) {
      const ret = {};
      for (const key of Object.keys(style)) {
        ret[key === 'CODE' ? 'monospace' : key.toLowerCase()] = style[key];
      }
      return ret;
    }
    return {};
  };

  useEffect(() => {
    const styles = getSelectionInlineStyle(editorState);
    setCurrentStyles(changeKeys(styles));
  }, [editorState]);

  return (
    <>
      <InlineToolbar
        onChange={toggleInlineStyle}
        currentState={currentStyles}
      />
    </>
  );
};

export default Toolbar;
